Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(634)

Unified Diff: runtime/vm/os_linux.cc

Issue 489923002: Tweaks to perf jitdump support (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/object.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/os_linux.cc
diff --git a/runtime/vm/os_linux.cc b/runtime/vm/os_linux.cc
index 1e6398ad48f6676c05eb28d0b718f658ad9c7c54..7a31892fe62b451b7d9de25222cc232ad71dc09c 100644
--- a/runtime/vm/os_linux.cc
+++ b/runtime/vm/os_linux.cc
@@ -151,16 +151,12 @@ class JitdumpCodeObserver : public CodeObserver {
if ((file_open == NULL) || (file_write == NULL) || (file_close == NULL)) {
return;
}
// The Jitdump code observer writes all jitted code into
// /tmp/jit-<pid>.dump, we open the file once on initialization and close
// it when the VM is going down.
{
// Open the file.
- const char* format = "/tmp/jit-%" Pd ".dump";
- intptr_t pid = getpid();
- intptr_t len = OS::SNPrint(NULL, 0, format, pid);
- char* filename = new char[len + 1];
- OS::SNPrint(filename, len + 1, format, pid);
+ const char* filename = "perf.jitdump";
out_file_ = (*file_open)(filename, true);
ASSERT(out_file_ != NULL);
// Write the jit dump header.
@@ -151,16 +151,12 @@ class JitdumpCodeObserver : public CodeObserver {
return;
}
- // The Jitdump code observer writes all jitted code into
- // /tmp/jit-<pid>.dump, we open the file once on initialization and close
- // it when the VM is going down.
+ // The Jitdump code observer writes all jitted code into the file
+ // 'perf.jitdump' in the current working directory. We open the file once
+ // on initialization and close it when the VM is going down.
{
// Open the file.
« no previous file with comments | « runtime/vm/object.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698